@@ -3,7 +3,8 @@
  *                                                                   
  * Xnee enables recording and replaying of X protocol data           
  *                                                                   
- *        Copyright (C) 1999, 2000, 2001, 2002, 2003 Henrik Sandklef
+ *        Copyright (C) 1999, 2000, 2001, 2002, 2003 
+ *                      2004, 2005, 2006 Henrik Sandklef
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
@@ -65,6 +66,7 @@ static char *help[] = {
   "--events-to-record <n>, -etr   ", "Intercept n numbers of events ( n<0 means forever)",
   "--data-to-record <n>, -dtr     ", "Intercept n numbers of data ( n<0 means forever)",
   "--seconds-to-record <n>, -str  ", "Intercept for n seconds ( n<0 means forever)",
+  "--recall-window-position, -rwp ", "Recall the recorded window position to be used during replay",
   "--verbose, -v                  ", "Verbose printout",
   "--buffer-verbose, -bv          ", "Verbose printout of replay buffer",
   "--time, -t  <secs>             ", "Delay start of application for <secs> seconds. Used to prevent recording of KeyRelease when starting Xnee from terminal",
@@ -527,6 +529,11 @@ xnee_parse_args (xnee_data* xd , int argc, char **argv )
 	  xnee_verbose ((xd, "CHECK ME ...buffer overflow ..... --seconds-to-record\n"));
 	  xnee_set_time_max (xd, atoi(argv[++i]));
 	}
+      else if(xnee_check(argv[i], "--recall-window-position", "-rwp")) 
+	{
+	  xnee_verbose ((xd, "--recall-window-position\n"));
+	  xnee_set_recall_window_pos (xd);
+	}
       else if(xnee_check(argv[i], "--stop-key", "-sk")) 
 	{
 	  xnee_verbose ((xd, "Found -sk/--stop ... : %s\n", argv[i]));
@@ -1060,14 +1067,14 @@ xnee_infopage (FILE *fd)
   char *descr;
 
   fprintf (fd ,"\\input texinfo  @c -*- Texinfo -*-\n");
-
-  fprintf (fd ,"@c %**start of header\n");
+  /* Thanks Peter for you remark on %% */
+  fprintf (fd ,"@c %%**start of header\n");
   fprintf (fd ,"@setfilename "XNEE_CLI".info\n");
-  fprintf (fd ," @set EDITION %s\n", VERSION);
-  fprintf (fd ," @set VERSION %s\n", VERSION);
+  fprintf (fd ,"@set EDITION %s\n", VERSION);
+  fprintf (fd ,"@set VERSION %s\n", VERSION);
   fprintf (fd ,"@settitle " XNEE_CLI " Manual \n");
   fprintf (fd ,"@setchapternewpage off\n");
-  fprintf (fd ,"@c %**end o\n");
+  fprintf (fd ,"@c %%**end o\n");
 
 
 
@@ -1140,7 +1147,7 @@ xnee_infopage (FILE *fd)
   fprintf (fd ,"\n");
 
   fprintf (fd, "@node Bugs, See also, Examples,top \n");
-  fprintf (fd, "If you envounter a bug, report it to ");
+  fprintf (fd, "If you encounter a bug, report it to ");
   fprintf (fd, "@indent @ @ @ @email{xnee-bug@@gnu.org}\n@ \n");
   fprintf (fd, "@indent or go to the Xnee site:\n");
   fprintf (fd, "@indent @ @ @ @url{http://svannah.gnu.org}\n@\n");
