@@ -268,6 +268,7 @@ xnee_init(xnee_data* xd)
   xd->sync          = True   ; 
   xd->mode          = XNEE_NOMODE   ; 
 
+  xd->xnee_info.store_window_pos = 0;
   
   /*@access FILE@*/
   xd->data_file     = (FILE*) stdin  ;
@@ -293,6 +294,7 @@ xnee_init(xnee_data* xd)
   xd->distr_list_size = 0   ;
   xd->cont          = True ;
   xd->force_replay  = False;
+  xnee_unset_recall_window_pos (xd);
   xd->first_read_time =0;
   
   xd->speed_percent = 100 ; 
