@@ -55,6 +55,8 @@ const char*  XNEE_EXEC_KEY             = "exec-key";
 const char*  XNEE_EXEC_PROGRAM         = "exec-program";
 const char*  XNEE_EXEC_NO_PROG         = "xnee-exec-no-program";
 const char*  XNEE_EXEC_MARK            = "EXEC";
+const char*  XNEE_NEW_WINDOW_MARK      = "NEW-WINDOW";
+const char*  XNEE_NEW_WINDOW           = "record-window-position";
 const char*  XNEE_EVERYTHING           = "everything";
 const char*  XNEE_DELAY_TIME           = "time";
 const char*  XNEE_SPEED_PERCENT        = "speed-percent";
